@@ -12,15 +12,16 @@
 // Qt
 #include <QFile>
 #include <QFileDialog>
-#include <QStandardPaths>
 #include <QStringList>
 #include <QTabBar>
 
 #include <QJsonArray>
 #include <QJsonDocument>
 
+#if HAVE_DBUS
 #include <QDBusArgument>
 #include <QDBusMetaType>
+#endif
 
 // KDE
 #include <KActionCollection>
@@ -30,7 +31,9 @@
 #include <KMessageBox>
 
 // Konsole
+#if HAVE_DBUS
 #include <windowadaptor.h>
+#endif
 
 #include "colorscheme/ColorScheme.h"
 #include "colorscheme/ColorSchemeManager.h"
@@ -62,7 +65,9 @@ ViewManager::ViewManager(QObject *parent, KActionCollection *collection)
     , _managerId(0)
     , _terminalDisplayHistoryIndex(-1)
 {
+#if HAVE_DBUS
     qDBusRegisterMetaType<QList<double>>();
+#endif
 
     _viewContainer = createContainer();
     // setup actions which are related to the views
@@ -77,11 +82,13 @@ ViewManager::ViewManager(QObject *parent, KActionCollection *collection)
     connect(ProfileManager::instance(), &Konsole::ProfileManager::profileChanged, this, &Konsole::ViewManager::profileChanged);
     connect(SessionManager::instance(), &Konsole::SessionManager::sessionUpdated, this, &Konsole::ViewManager::updateViewsForSession);
 
+    _managerId = ++lastManagerId;
+
+#if HAVE_DBUS
     // prepare DBus communication
     new WindowAdaptor(this);
-
-    _managerId = ++lastManagerId;
     QDBusConnection::sessionBus().registerObject(QLatin1String("/Windows/") + QString::number(_managerId), this);
+#endif
 }
 
 ViewManager::~ViewManager() = default;
@@ -171,7 +178,7 @@ void ViewManager::setupActions()
     action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-top-bottom")));
     action->setText(i18nc("@action:inmenu", "Load a new tab with layout 2x2 terminals"));
     connect(action, &QAction::triggered, this, [this]() {
-        this->loadLayout(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/2x2-terminals.json")));
+        this->loadLayout(QStringLiteral(":/konsole/layouts/2x2-terminals.json"));
     });
     collection->addAction(QStringLiteral("load-terminals-layout-2x2"), action);
     splitViewActions->addAction(action);
@@ -180,7 +187,7 @@ void ViewManager::setupActions()
     action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-left-right")));
     action->setText(i18nc("@action:inmenu", "Load a new tab with layout 2x1 terminals"));
     connect(action, &QAction::triggered, this, [this]() {
-        this->loadLayout(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/2x1-terminals.json")));
+        this->loadLayout(QStringLiteral(":/konsole/layouts/2x1-terminals.json"));
     });
     collection->addAction(QStringLiteral("load-terminals-layout-2x1"), action);
     splitViewActions->addAction(action);
@@ -189,7 +196,7 @@ void ViewManager::setupActions()
     action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-top-bottom")));
     action->setText(i18nc("@action:inmenu", "Load a new tab with layout 1x2 terminals"));
     connect(action, &QAction::triggered, this, [this]() {
-        this->loadLayout(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/1x2-terminals.json")));
+        this->loadLayout(QStringLiteral(":/konsole/layouts/1x2-terminals.json"));
     });
     collection->addAction(QStringLiteral("load-terminals-layout-1x2"), action);
     splitViewActions->addAction(action);
@@ -775,6 +782,7 @@ void ViewManager::splitView(Qt::Orientation orientation, bool fromNextTab)
         auto *session = createSession(profile, directory);
 
         focused = terminalDisplay = createView(session);
+        Q_EMIT activeViewChanged(activeViewController());
     }
 
     _viewContainer->splitView(terminalDisplay, orientation);
